==> haskell-hls-overloaded-record-dot-plugin-2.1.0.0-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-overloaded-record-dot-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-overloaded-record-dot-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-overloaded-record-dot-plugin-2.1.0.0-8hsd3tgxGcMCZAr8M4PJuQ

key:
    hls-overloaded-record-dot-plugin-2.1.0.0-8hsd3tgxGcMCZAr8M4PJuQ

license:              BSD-3-Clause
maintainer:           joyfulmantis@gmail.com
author:               Nathan Maxson
synopsis:             Overloaded record dot plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  f3d85ef7ab113b18f93ef3234427a77b
exposed:              True
exposed-modules:      Ide.Plugin.OverloadedRecordDot
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-overloaded-record-dot-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-overloaded-record-dot-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-overloaded-record-dot-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-overloaded-record-dot-plugin
hs-libraries:
    HShls-overloaded-record-dot-plugin-2.1.0.0-8hsd3tgxGcMCZAr8M4PJuQ

depends:
    aeson-2.1.2.1-6q2KNYwRaL29rPm6MMaiUC base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 ghc-boot-th-9.4.8
    ghcide-2.1.0.0-1KOcaMBafULLEncWomo7Qk
    hls-graph-2.1.0.0-8gz4dmxk15l37hnwvJlpMG
    hls-plugin-api-2.1.0.0-KSS8kWBQYXNJC6hz6fAtRu
    lens-5.3.1-LF4jCoE0w776e2gq32lhyl
    lsp-2.1.0.0-JpAybzOu2bA4LGzZcHHGTh
    syb-0.7.2.4-Au9jUQxtdeJGhFGXkWlbWz text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-3NcLl7S6t7kAuh7l4Ieeoo

haddock-interfaces:
    /usr/share/doc/haskell-hls-overloaded-record-dot-plugin/html/hls-overloaded-record-dot-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-overloaded-record-dot-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-overloaded-record-dot-plugin-2.1.0.0-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-overloaded-record-dot-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-overloaded-record-dot-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-overloaded-record-dot-plugin-2.1.0.0-IH1NwkTzyLq4t75DDolhqQ

key:
    hls-overloaded-record-dot-plugin-2.1.0.0-IH1NwkTzyLq4t75DDolhqQ

license:              BSD-3-Clause
maintainer:           joyfulmantis@gmail.com
author:               Nathan Maxson
synopsis:             Overloaded record dot plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  541e60ee123efeafa0766d2fff6be9c7
exposed:              True
exposed-modules:      Ide.Plugin.OverloadedRecordDot
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-overloaded-record-dot-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-overloaded-record-dot-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-overloaded-record-dot-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-overloaded-record-dot-plugin
hs-libraries:
    HShls-overloaded-record-dot-plugin-2.1.0.0-IH1NwkTzyLq4t75DDolhqQ

depends:
    aeson-2.1.2.1-6q2KNYwRaL29rPm6MMaiUC base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 ghc-boot-th-9.4.8
    ghcide-2.1.0.0-8JBpStbo1B4AALTMcYIo2m
    hls-graph-2.1.0.0-JleQUiuXhcQ3TRrPGA2Xbg
    hls-plugin-api-2.1.0.0-H3CXeXeKkzR8GXL5hkOqhn
    lens-5.3.1-LF4jCoE0w776e2gq32lhyl
    lsp-2.1.0.0-7xFRPbjxdPZ8y4wRPhO8AZ
    syb-0.7.2.4-Au9jUQxtdeJGhFGXkWlbWz text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-3NcLl7S6t7kAuh7l4Ieeoo

haddock-interfaces:
    /usr/share/doc/haskell-hls-overloaded-record-dot-plugin/html/hls-overloaded-record-dot-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-overloaded-record-dot-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
